class classificationModel : 

    def __init__(self) : 
        self.model = None
        self.std_out = None

    def load(self) : 
        self.std_out = "Hello Moom!!!"
        return self.std_out

    def predict(self) : 
        self.std_out = "How are you!"
        return self.std_out
